@@ -27,10 +27,10 @@ from .bark_bands import bark_bands_sone
 from .loudness import loudness
 from .loudness import essentia_loudness
 from .sharpness import sharpness
+from .hpcp import hpcp
+from .melodia import melodia
 
 from .base_features import get_mfcc
-from .roughness import hpcp
-# from .base_features import get_melody
 from .base_features import get_beats
 from .base_features import get_onsets
 
